@@ -43,7 +43,8 @@ unset INSTALLER_CD      || true
 unset DI_CODENAME       || true
 unset MAXCDS            || true
 unset SPLASHPNG         || true
-unset OMIT_MANUAL	|| true
+unset OMIT_MANUAL	    || true
+unset OMIT_RELEASE_NOTES || true
 
 # The debian-cd dir
 # Where I am (hoping I'm in the debian-cd dir)
@@ -75,7 +76,7 @@ export OFFICIAL="Unofficial"
 #export OFFICIAL="Official Beta"
 
 # ... for arch  
-export ARCH=`dpkg --print-installation-architecture`
+export ARCH=`dpkg --print-architecture`
 
 # IMPORTANT : The 4 following paths must be on the same partition/device.
 #	      If they aren't then you must set COPYLINK below to 1. This
@@ -165,14 +166,14 @@ export DEFBINSIZE=630
 export DEFSRCSIZE=635
 
 # We don't want certain packages to take up space on CD1...
-export EXCLUDE="$BASEDIR"/tasks/exclude-sarge
+export EXCLUDE="$BASEDIR"/tasks/exclude-$CODENAME
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included on CD >= x)
-export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-sarge
+export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
 # Any packages listed in EXCLUDE but not in any UNEXCLUDE will be
 # excluded completely.
 
 # We also exclude some source packages
-#export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-potato
+#export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-$CODENAME
 
 # Set this if the recommended packages should be skipped when adding 
 # package on the CD.  The default is 'false'.
@@ -288,3 +289,10 @@ export PUBLISH_PATH="/home/jigdo-area/"
 # Set to 1 to save space by omitting the installation manual. 
 # If so the README will link to the manual on the web site.
 #export OMIT_MANUAL=1
+
+# Set to 1 to save space by omitting the release notes
+# If so we will link to them on the web site.
+export OMIT_RELEASE_NOTES=0
+
+# Set this to override the defaul location
+#export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
