@@ -74,7 +74,7 @@ export OFFICIAL="Unofficial"
 #export OFFICIAL="Official Beta"
 
 # ... for arch  
-export ARCH=`dpkg --print-installation-architecture`
+export ARCH=`dpkg --print-architecture`
 
 # IMPORTANT : The 4 following paths must be on the same partition/device.
 #	      If they aren't then you must set COPYLINK below to 1. This
@@ -164,14 +164,14 @@ export DEFBINSIZE=630
 export DEFSRCSIZE=635
 
 # We don't want certain packages to take up space on CD1...
-export EXCLUDE="$BASEDIR"/tasks/exclude-sarge
+export EXCLUDE="$BASEDIR"/tasks/exclude-$CODENAME
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included on CD >= x)
-export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-sarge
+export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
 # Any packages listed in EXCLUDE but not in any UNEXCLUDE will be
 # excluded completely.
 
 # We also exclude some source packages
-#export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-potato
+#export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-$CODENAME
 
 # Set this if the recommended packages should be skipped when adding 
 # package on the CD.  The default is 'false'.
